@@ -751,25 +751,26 @@ void vtkSIProxyDefinitionManager::SaveCustomProxyDefinitions(vtkPVXMLElement* ro
 //---------------------------------------------------------------------------
 bool vtkSIProxyDefinitionManager::LoadConfigurationXMLFromString(const char* xmlContent)
 {
-  return this->LoadConfigurationXMLFromString(xmlContent, false);
+  return this->LoadConfigurationXMLFromString(xmlContent, false, true);
 }
 //---------------------------------------------------------------------------
 bool vtkSIProxyDefinitionManager::LoadConfigurationXMLFromString(
-  const char* xmlContent, bool attachHints)
+  const char* xmlContent, bool attachHints, bool invoke)
 {
   vtkNew<vtkPVXMLParser> parser;
   return (parser->Parse(xmlContent) != 0) &&
-    this->LoadConfigurationXML(parser->GetRootElement(), attachHints);
+    this->LoadConfigurationXML(parser->GetRootElement(), attachHints, invoke);
 }
 
 //---------------------------------------------------------------------------
 bool vtkSIProxyDefinitionManager::LoadConfigurationXML(vtkPVXMLElement* root)
 {
-  return this->LoadConfigurationXML(root, false);
+  return this->LoadConfigurationXML(root, false, true);
 }
 
 //---------------------------------------------------------------------------
-bool vtkSIProxyDefinitionManager::LoadConfigurationXML(vtkPVXMLElement* root, bool attachHints)
+bool vtkSIProxyDefinitionManager::LoadConfigurationXML(
+  vtkPVXMLElement* root, bool attachHints, bool invoke)
 {
   if (!root)
   {
@@ -807,7 +808,11 @@ bool vtkSIProxyDefinitionManager::LoadConfigurationXML(vtkPVXMLElement* root, bo
       }
     }
   }
-  this->InvokeEvent(vtkSIProxyDefinitionManager::ProxyDefinitionsUpdated);
+
+  if (invoke)
+  {
+    this->InvokeEvent(vtkSIProxyDefinitionManager::ProxyDefinitionsUpdated);
+  }
   return true;
 }
 
@@ -998,7 +1003,6 @@ void vtkSIProxyDefinitionManager::MergeProxyDefinition(
         vtkPVXMLElement* overridingProxyDef = subProxySrc[name].GetPointer();
         subProxyDefToRemove->GetParent()->ReplaceNestedElement(
           subProxyDefToRemove, overridingProxyDef);
-        overridingProxyDef->GetParent()->RemoveNestedElement(overridingProxyDef);
       }
     }
     // Move to next
@@ -1029,7 +1033,6 @@ void vtkSIProxyDefinitionManager::MergeProxyDefinition(
         vtkPVXMLElement* subPropDefToRemove = propertiesToFill[name].GetPointer();
         vtkPVXMLElement* overridingProp = propertiesSrc[name].GetPointer();
         subPropDefToRemove->GetParent()->ReplaceNestedElement(subPropDefToRemove, overridingProp);
-        overridingProp->GetParent()->RemoveNestedElement(overridingProp);
       }
     }
     // Move to next
@@ -1049,9 +1052,19 @@ void vtkSIProxyDefinitionManager::MergeProxyDefinition(
   for (cc = 0; cc < numChildren; cc++)
   {
     vtkPVXMLElement* child = element->GetNestedElement(cc);
-    vtkNew<vtkPVXMLElement> newElement;
-    child->CopyTo(newElement.GetPointer());
-    elementToFill->AddNestedElement(newElement.GetPointer());
+    bool addProperty = true;
+    if (child->GetAttribute("override"))
+    {
+      // Only include properties with an override attribute if they are
+      // absent from the element to fill.
+      addProperty = !elementToFill->FindNestedElementByName(child->GetName());
+    }
+    if (addProperty)
+    {
+      vtkNew<vtkPVXMLElement> newElement;
+      child->CopyTo(newElement.GetPointer());
+      elementToFill->AddNestedElement(newElement.GetPointer());
+    }
   }
 }
 
@@ -1192,12 +1205,13 @@ void vtkSIProxyDefinitionManager::HandlePlugin(vtkPVPlugin* plugin)
         this->LoadConfigurationXMLFromString(xmls[cc].c_str(),
           // if GetPluginName() == vtkPVInitializerPlugin, it implies that it's
           // the ParaView core and should not be treated as plugin.
-          strcmp(plugin->GetPluginName(), "vtkPVInitializerPlugin") != 0);
+          strcmp(plugin->GetPluginName(), "vtkPVInitializerPlugin") != 0, false);
       }
 
       // Make sure we invalidate any cached flatten version of our proxy definition
       this->InternalsFlatten->Clear();
       this->Internals->ReplaceOverrideInParent = tmpReplaceOverrideInParent;
+      this->InvokeEvent(vtkSIProxyDefinitionManager::ProxyDefinitionsUpdated);
     }
   }
 }
